==> tencentcloud_sdk_python-3.0.854-py2.py3-none-any.whl: tencentcloud/memcached/v20190318/memcached_client.py <==
# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.common.abstract_client import AbstractClient
from tencentcloud.memcached.v20190318 import models


class MemcachedClient(AbstractClient):
    _apiVersion = '2019-03-18'
    _endpoint = 'memcached.tencentcloudapi.com'
    _service = 'memcached'


    def DescribeInstances(self, request):
        """获取Cmem实例列表

        :param request: Request instance for DescribeInstances.
        :type request: :class:`tencentcloud.memcached.v20190318.models.DescribeInstancesRequest`
        :rtype: :class:`tencentcloud.memcached.v20190318.models.DescribeInstancesResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeInstances", params, headers=headers)
            response = json.loads(body)
            model = models.DescribeInstancesResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)

==> tencentcloud_sdk_python-3.0.1444-py2.py3-none-any.whl: tencentcloud/memcached/v20190318/memcached_client.py <==
# -*- coding: utf8 -*-
# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.common.abstract_client import AbstractClient
from tencentcloud.memcached.v20190318 import models


class MemcachedClient(AbstractClient):
    _apiVersion = '2019-03-18'
    _endpoint = 'memcached.tencentcloudapi.com'
    _service = 'memcached'


    def DescribeInstances(self, request):
        """获取Cmem实例列表

        :param request: Request instance for DescribeInstances.
        :type request: :class:`tencentcloud.memcached.v20190318.models.DescribeInstancesRequest`
        :rtype: :class:`tencentcloud.memcached.v20190318.models.DescribeInstancesResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeInstances", params, headers=headers)
            response = json.loads(body)
            model = models.DescribeInstancesResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))
